import { useState } from 'react';
import { motion, AnimatePresence } from 'framer-motion';

interface Tab {
  id: string;
  label: string;
  icon?: React.ReactNode;
}

interface TabPanelProps {
  tabs: Tab[];
  children: React.ReactNode[];
  defaultTab?: string;
  className?: string;
}

export default function TabPanel({ 
  tabs, 
  children, 
  defaultTab,
  className = ''
}: TabPanelProps) {
  const [activeTab, setActiveTab] = useState(defaultTab || tabs[0].id);

  return (
    <div className={`bg-[#1a1a1a] rounded-lg shadow-lg ${className}`}>
      {/* Tab Headers */}
      <div className="border-b border-[#2a2a2a]">
        <nav className="flex -mb-px">
          {tabs.map((tab) => (
            <button
              key={tab.id}
              onClick={() => setActiveTab(tab.id)}
              className={`
                group relative min-w-0 flex-1 overflow-hidden py-4 px-6 text-sm font-medium text-center
                hover:bg-[#2a2a2a] focus:z-10 focus:outline-none transition-colors
                ${activeTab === tab.id
                  ? 'text-[#FF6B2B] border-b-2 border-[#FF6B2B]'
                  : 'text-gray-400 border-b-2 border-transparent hover:text-gray-300'
                }
              `}
            >
              <div className="flex items-center justify-center space-x-2">
                {tab.icon && (
                  <span className={`w-5 h-5 ${
                    activeTab === tab.id ? 'text-[#FF6B2B]' : 'text-gray-400'
                  }`}>
                    {tab.icon}
                  </span>
                )}
                <span>{tab.label}</span>
              </div>

              {/* Active Indicator */}
              {activeTab === tab.id && (
                <motion.div
                  layoutId="activeTab"
                  className="absolute bottom-0 inset-x-0 h-0.5 bg-[#FF6B2B]"
                />
              )}
            </button>
          ))}
        </nav>
      </div>

      {/* Tab Content */}
      <div className="p-6">
        <AnimatePresence mode="wait">
          {children.map((child, index) => {
            if (tabs[index].id !== activeTab) return null;
            return (
              <motion.div
                key={tabs[index].id}
                initial={{ opacity: 0, y: 10 }}
                animate={{ opacity: 1, y: 0 }}
                exit={{ opacity: 0, y: -10 }}
                transition={{ duration: 0.2 }}
              >
                {child}
              </motion.div>
            );
          })}
        </AnimatePresence>
      </div>
    </div>
  );
} 